@@ -2,7 +2,7 @@ use strict;
 use warnings;
 use utf8;
 
-package Dist::Zilla::Path 6.000; # TRIAL
+package Dist::Zilla::Path 6.002; # TRIAL
 # ABSTRACT: a helper to get Path::Tiny objects
 
 use parent 'Path::Tiny';
@@ -27,16 +27,25 @@ sub path {
   return bless(Path::Tiny::path($thing, @rest), __PACKAGE__);
 }
 
+my %warned;
+
 sub file {
   my ($self, @file) = @_;
+
+  my ($package, $pmfile, $line) = caller;
+  unless ($warned{ $pmfile, $line }++) {
+    Carp::carp("->file called on a Dist::Zilla::Path object; this will cease to work in Dist::Zilla v7; downstream code should be updated to use Path::Tiny API, not Path::Class");
+  }
+
   require Path::Class;
   Path::Class::dir($self)->file(@file);
 }
 
 sub subdir {
   my ($self, @subdir) = @_;
+  Carp::carp("->subdir called on a Dist::Zilla::Path object; this will cease to work in Dist::Zilla v7; downstream code should be updated to use Path::Tiny API, not Path::Class");
   require Path::Class;
-  Path::Class::dir($self)->file(@subdir);
+  Path::Class::dir($self)->subdir(@subdir);
 }
 
 1;
@@ -53,7 +62,7 @@ Dist::Zilla::Path - a helper to get Path::Tiny objects
 
 =head1 VERSION
 
-version 6.000
+version 6.002
 
 =head1 AUTHOR
 
